# Quality Assurance: Google Search Manual Testing

## Purpose

The purpose of this assignment is to gain insight about your knowledge/skills in manual browser testing, as well as in test-planning under time & resource constraints.

## Timeline

**Assignment time-limit**: **2 hours** [_after_ reading this page]

[Given] **Tester resource-budget**: **1.5 hours**

You&rsquo;re _not_ expected to demonstrate complete knowledge of QA best practices in this very limited assignment.

## Your tasks

Read ALL instructions before starting tasks. [Reading time not counted toward assignment time-limit.]

### Overview

**Tasks**:

- Check Google Search **[**requirements**]** [scroll down] & related functionality
- Write & submit 3 top-priority\* **Test Cases**
- Write & submit a **Test Plan**\*\*

**Deliverables**:

- 3 Test Cases
- 1 Test Plan

\*Assignment time-limit precludes requiring more than 3 test-cases. There should ideally be many more.

\*\*For test-planning, strike a sensible coverage-balance between subfeatures [in your Test Cases] and number of OS-browser combos [in your Test Plan].

### Instructions

Complete the following tasks in **2 hours maximum**:

1. Familiarize yourself with Google Search:

   - No need to include this info in your submission.
   - Review the **Requirements** section [at bottom of page].
   - Check related functionality of the following main features at https://google.com/ [not the mobile app]:
     - Search field [textbox]
     - Results list
     - Results toolbar

2. **Write & submit 3 Manual-UI Acceptance Test Cases**, using a plain-text file:

   - **Constraint**: Only **1.5 person-hours of total tester capacity** is budgeted &mdash; all 3 Test Cases will be run across all the OS/browser combinations you list as in-scope in your Test Plan.
   - Write only happy-path cases – no need to include negative testing.
   - Validate major, top-priority functional features & subfeatures &mdash; should fit under tester resource-budget.
   - Validate functionality only -- no need to validate accessibility, content/styling, or performance
   - Include time estimate for each case.
   - You may cover 2 or more high-level-requirements in the same case
   - Write steps for non-technical user [with basic computer/smartphone & web-surfing skills].
   - Include expected result for each test step.

3. **Write & submit a small Test Plan** for above cases, continuing in the same plain-text file.:

   - Constraints: Constraint: Only **1.5 person-hours of total tester capacity** is budgeted &mdash; all 3 Test Cases will be run across all the OS/browser combinations you list as in-scope in your Test Plan.
   - Omit high-level planning-items – no need to include:
     - Product analysis
     - Strategy
     - Other types of testing
     - Specific testing frameworks/tools/systems
     - Deliverables
   - Document & explain test scope:
     - Features/subfeatures to cover [a synopsis of your test cases]
     - OS/browser combinations to cover
   - Update your Test Cases’ subfeature-coverage as needed for tester resource-budget.

### Submission

- Submit your homework in a **single, plain-text (.txt) file**. Currently, we’re unable to accept alternative file types by default as we’re still figuring out how to consistently anonymize submissions.

### Google Search Requirements

The requirements listed below are **high-level**, and selected to fit assignment & tester-capacity time-limits. They also do not include all implementation details or subfeatures/options -- those are to be fleshed out in your Test Cases.

For example, "Search is submitted" below could be fleshed out in a test-step as `Tap Search button [mobile] or press Enter key [desktop]`.

#### Entry URL

https://google.com/ [not the mobile Google app]

#### <span id="rqmts">High-level requirements</span>

| ID  | Given                           | When                                           | Then                                                                   |
| --- | ------------------------------- | ---------------------------------------------- | ---------------------------------------------------------------------- |
| R1  | "qa" is typed into search field | Search is submitted                            | Browser loads results relevant to "qa"                                 |
| R2  | Results are loaded              | Navigation link is tapped/clicked              | Browser navigates to destination page                                  |
| R3  | Results are loaded              | Category-tab is selected                       | Browser displays only category-specific results                        |
| R4  | Results are loaded              | Recency-option is selected from Tools dropdown | Browser displays only results posted/updated within selected timeframe |

### Any questions?

If you have any specific questions about this homework assignment, please contact VA Applications Shared Support Team:

- Tze Lei, Sr. Software/QA Engineer (tze@adhocteam.us), or
- Eli Mellen, Product Manager (eli.mellen@adhocteam.us)

For general questions, you can click the green **Ask a homework question** button at the lower-right of this page.
